Package: ILSAstats
Type: Package
Title: Statistics for International Large-Scale Assessments (ILSA)
Version: 0.4.5
Authors@R: c(person(given = "Andrés",
                    family = "Christiansen",
                    role = c("aut","cre"),
                    email = "andres.christiansen@iea-hamburg.de",
                    comment = c(ORCID = "0000-0003-2692-7843")),
                    person(given = "Andrés", family = "Strello",
                    role = c("ctb"),comment = c(ORCID = "0000-0002-5613-8338")))
Maintainer: Andrés Christiansen <andres.christiansen@iea-hamburg.de>
Description: Calculates point estimates and standard errors using replicate weights and plausible values for International Large-Scale Assessments (ILSA), including: means, proportions, quantiles, correlations, singlelevel regressions, and multilevel regressions.
Encoding: UTF-8
LazyData: true
LazyDataCompression: xz
BuildResaveData: best
RoxygenNote: 7.3.3
Suggests: wCorr, lme4, MuMIn, WeMix, knitr, rmarkdown
Depends: R (>= 3.5.0)
License: GPL (>= 3)
VignetteBuilder: knitr
URL: https://dopatendo.github.io/ILSAstats/
NeedsCompilation: no
Packaged: 2026-04-03 09:45:21 UTC; andreschristiansen
Author: Andrés Christiansen [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-2692-7843>),
  Andrés Strello [ctb] (ORCID: <https://orcid.org/0000-0002-5613-8338>)
Repository: CRAN
Date/Publication: 2026-04-03 10:00:02 UTC
Built: R 4.6.0; ; 2026-04-26 20:11:19 UTC; unix
