# Generated by roxygen2: do not edit by hand

S3method(print,WeMixPV)
S3method(print,autoILSA)
S3method(print,leaguetable)
S3method(print,lmerPV)
S3method(print,proflevels)
S3method(print,repglm)
S3method(print,repglm.group)
S3method(print,repglm.pv)
S3method(print,replm)
S3method(print,replm.group)
S3method(print,replm.pv)
S3method(print,repmean)
S3method(print,repmean.complex)
S3method(print,repmeanCI)
S3method(print,repmeandif)
S3method(print,repprop)
S3method(print,repquant)
S3method(print,reprho)
S3method(print,repsetup)
S3method(print,repweights.index)
S3method(summary,repmean.complex)
export(WeMixPV)
export(autoILSA)
export(center)
export(getgroup.mean)
export(grand.mean)
export(group.mean)
export(icc)
export(leaguetable)
export(lmerPV)
export(prepILSA)
export(proflevels)
export(proflevels.get)
export(pvse)
export(repcreate)
export(repcreateILSA)
export(repglm)
export(replm)
export(repmean)
export(repmeanCI)
export(repmeandif)
export(repprop)
export(repprop.table)
export(repquant)
export(reprho)
export(repse)
export(repsecomp)
export(repsetup)
export(repsetupILSA)
